@@ -1,7 +1,7 @@
 /* Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
- * This file is part of pdfdjvu.
+ * This file is part of pdf2djvu.
  *
  * pdf2djvu is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -671,7 +671,17 @@ void pdf_outline_to_djvu_outline(pdf::Object *node, pdf::Catalog *catalog,
           throw NoPageForBookmark();
         if (link_action.get() == NULL || link_action->getKind() != actionGoTo)
           throw NoPageForBookmark();
-        page = get_page_for_LinkGoTo(dynamic_cast<pdf::link::GoTo*>(link_action.get()), catalog);
+        try
+        {
+          page = get_page_for_LinkGoTo(
+            dynamic_cast<pdf::link::GoTo*>(link_action.get()),
+            catalog
+          );
+        }
+        catch (NoLinkDestination &ex)
+        {
+          throw NoPageForBookmark();
+        }
       }
       {
         djvu::OutlineItem &djvu_outline_item = djvu_outline.add(
