@@ -1,7 +1,7 @@
 /* Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
- * This file is part of pdfdjvu.
+ * This file is part of pdf2djvu.
  *
  * pdf2djvu is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -15,11 +15,13 @@
 
 #if !WIN32
 
+#include "autoconf.hh"
 #include "system.hh"
 
 #include <cassert>
 #include <cerrno>
 #include <cstdio>
+#include <cstddef>
 #include <cstdlib>
 #include <cstring>
 #include <csignal>
@@ -37,6 +39,7 @@
 #endif
 
 #include "array.hh"
+#include "string-printf.hh"
 #include "i18n.hh"
 
 Command::Command(const std::string& command) : command(command)
